@@ -14,6 +14,8 @@
 from __future__ import absolute_import, division, print_function
 from __future__ import unicode_literals
 
+import psycopg2cffi.compat
+
 from warehouse.__about__ import (
     __title__, __summary__, __uri__, __version__, __author__, __email__,
     __license__, __copyright__, __build__,
@@ -23,3 +25,6 @@ __all__ = [
     "__title__", "__summary__", "__uri__", "__version__", "__author__",
     "__email__", "__license__", "__copyright__", "__build__",
 ]
+
+
+psycopg2cffi.compat.register()
