@@ -24,4 +24,7 @@ urls = [
         ]),
         Rule("/packages/<path:path>", methods=["GET"], endpoint="package"),
     ]),
+    EndpointPrefix("warehouse.legacy.pypi.", [
+        Rule("/pypi", methods=["GET", "POST"], endpoint="pypi"),
+    ]),
 ]
